/****************************************************************************************
 * Copyright (C) 2012 Lucien XU <sfietkonstantin@free.fr>                               *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 3 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/


import QtQuick 1.1
import QtMobility.systeminfo 1.2
import com.nokia.meego 1.0

PageStackWindow {
    id: window
    initialPage: mainPage
    Component.onCompleted: {
        theme.inverted = true
        checkTimerToRun()
    }

    function checkTimerToRun() {
        if (platformWindow.active && platformWindow.visible) {
            alignedTimer.stop()
            timer.start()
        } else {
            alignedTimer.start()
            timer.stop()
        }
        mainPage.update()
    }

    Page {
        id: mainPage

        function update()  {
            var remainingMsec = TimeComputer.remainingMsec()
            days.text = qsTr("%n days", "", TimeComputer.remainingDays(remainingMsec))
            minimizedDays.text = days.text
            time.text = Qt.formatTime(TimeComputer.remainingTime(remainingMsec), "HH:mm:ss:zzz")
        }

        Item {
            anchors.top: parent.top; anchors.left: parent.left
            width: window.inPortrait ? mainPage.width : mainPage.width / 2
            height: window.inPortrait ? mainPage.height / 2 : mainPage.height

            Image {
                anchors.centerIn: parent
                source: "Jolla_logo.png"
                smooth: true
            }
        }

        Item {
            anchors.bottom: parent.bottom; anchors.right: parent.right
            width: window.inPortrait ? mainPage.width : mainPage.width / 2
            height: window.inPortrait ? mainPage.height / 2 : mainPage.height

            Item {
                anchors.centerIn: parent
                width: parent.width
                height: days.height + 5 + time.height

                Label {
                    id: days
                    anchors.horizontalCenter: parent.horizontalCenter
                    font.family: "Courier"
                    color: "white"
                    font.pixelSize: 50
                    visible: !screen.minimized
                }

                Label {
                    id: time
                    anchors.top: days.bottom; anchors.topMargin: 5
                    anchors.horizontalCenter: parent.horizontalCenter
                    font.family: "Courier"
                    color: "white"
                    font.pixelSize: 50
                    visible: !screen.minimized
                }

                Label {
                    id: minimizedDays
                    anchors.centerIn: parent
                    font.family: "Courier"
                    color: "white"
                    font.pixelSize: 50
                    visible: screen.minimized
                }
            }
        }

        AlignedTimer {
            id: alignedTimer
            minimumInterval: 1
            maximumInterval: 60
            singleShot: false
            onTimeout: mainPage.update()
        }

        Timer {
            id: timer
            interval: 16
            repeat: true
            onTriggered: mainPage.update()
        }

        Connections {
            target: platformWindow
            onActiveChanged: window.checkTimerToRun()
            onVisibleChanged: window.checkTimerToRun()
        }
    }
}
